From a558ee0b572d5b634b5d760b6575127e1e13d91c Mon Sep 17 00:00:00 2001
From: Bernhard Schuster <bernhard@ahoi.io>
Date: Thu, 16 Dec 2021 18:16:41 +0100
Subject: [PATCH] naming consistency (#4539)

---
 polkadot/bridges/bin/rialto/node/src/overseer.rs     |  2 +-
 polkadot/node/core/provisioner/src/lib.rs            | 12 ++++++------
 .../node/network/statement-distribution/src/lib.rs   | 12 ++++++------
 .../node/network/statement-distribution/src/tests.rs |  8 ++++----
 polkadot/node/service/src/overseer.rs                |  4 ++--
 5 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/polkadot/bridges/bin/rialto/node/src/overseer.rs b/polkadot/bridges/bin/rialto/node/src/overseer.rs
index 9a7025e77c9..488a6649047 100644
--- a/polkadot/bridges/bin/rialto/node/src/overseer.rs
+++ b/polkadot/bridges/bin/rialto/node/src/overseer.rs
@@ -65,7 +65,7 @@ pub use polkadot_node_core_chain_selection::ChainSelectionSubsystem;
 pub use polkadot_node_core_dispute_coordinator::DisputeCoordinatorSubsystem;
 pub use polkadot_node_core_provisioner::ProvisionerSubsystem;
 pub use polkadot_node_core_runtime_api::RuntimeApiSubsystem;
-pub use polkadot_statement_distribution::StatementDistribution as StatementDistributionSubsystem;
+pub use polkadot_statement_distribution::StatementDistributionSubsystem;
 
 /// Arguments passed for overseer construction.
 pub struct OverseerGenArgs<'a, Spawner, RuntimeClient>
diff --git a/polkadot/node/network/statement-distribution/src/lib.rs b/polkadot/node/network/statement-distribution/src/lib.rs
index d6ca288165a..2194aa806a6 100644
--- a/polkadot/node/network/statement-distribution/src/lib.rs
+++ b/polkadot/node/network/statement-distribution/src/lib.rs
@@ -104,7 +104,7 @@ const LOG_TARGET: &str = "parachain::statement-distribution";
 const MAX_LARGE_STATEMENTS_PER_SENDER: usize = 20;
 
 /// The statement distribution subsystem.
-pub struct StatementDistribution {
+pub struct StatementDistributionSubsystem {
 	/// Pointer to a keystore, which is required for determining this node's validator index.
 	keystore: SyncCryptoStorePtr,
 	/// Receiver for incoming large statement requests.
@@ -113,7 +113,7 @@ pub struct StatementDistribution {
 	metrics: Metrics,
 }
 
-impl<Context> overseer::Subsystem<Context, SubsystemError> for StatementDistribution
+impl<Context> overseer::Subsystem<Context, SubsystemError> for StatementDistributionSubsystem
 where
 	Context: SubsystemContext<Message = StatementDistributionMessage>,
 	Context: overseer::SubsystemContext<Message = StatementDistributionMessage>,
@@ -131,14 +131,14 @@ where
 	}
 }
 
-impl StatementDistribution {
+impl StatementDistributionSubsystem {
 	/// Create a new Statement Distribution Subsystem
 	pub fn new(
 		keystore: SyncCryptoStorePtr,
 		req_receiver: IncomingRequestReceiver<request_v1::StatementFetchingRequest>,
 		metrics: Metrics,
-	) -> StatementDistribution {
-		StatementDistribution { keystore, req_receiver: Some(req_receiver), metrics }
+	) -> Self {
+		Self { keystore, req_receiver: Some(req_receiver), metrics }
 	}
 }
 
@@ -1535,7 +1535,7 @@ async fn handle_network_update(
 	}
 }
 
-impl StatementDistribution {
+impl StatementDistributionSubsystem {
 	async fn run(
 		mut self,
 		mut ctx: (impl SubsystemContext<Message = StatementDistributionMessage>
diff --git a/polkadot/node/network/statement-distribution/src/tests.rs b/polkadot/node/network/statement-distribution/src/tests.rs
index afe1d59f020..41263a6862b 100644
--- a/polkadot/node/network/statement-distribution/src/tests.rs
+++ b/polkadot/node/network/statement-distribution/src/tests.rs
@@ -703,7 +703,7 @@ fn receiving_from_one_sends_to_another_and_to_candidate_backing() {
 	let (statement_req_receiver, _) = IncomingRequest::get_config_receiver();
 
 	let bg = async move {
-		let s = StatementDistribution::new(
+		let s = StatementDistributionSubsystem::new(
 			Arc::new(LocalKeystore::in_memory()),
 			statement_req_receiver,
 			Default::default(),
@@ -895,7 +895,7 @@ fn receiving_large_statement_from_one_sends_to_another_and_to_candidate_backing(
 	let (statement_req_receiver, mut req_cfg) = IncomingRequest::get_config_receiver();
 
 	let bg = async move {
-		let s = StatementDistribution::new(
+		let s = StatementDistributionSubsystem::new(
 			make_ferdie_keystore(),
 			statement_req_receiver,
 			Default::default(),
@@ -1394,7 +1394,7 @@ fn share_prioritizes_backing_group() {
 	let (statement_req_receiver, mut req_cfg) = IncomingRequest::get_config_receiver();
 
 	let bg = async move {
-		let s = StatementDistribution::new(
+		let s = StatementDistributionSubsystem::new(
 			make_ferdie_keystore(),
 			statement_req_receiver,
 			Default::default(),
@@ -1679,7 +1679,7 @@ fn peer_cant_flood_with_large_statements() {
 
 	let (statement_req_receiver, _) = IncomingRequest::get_config_receiver();
 	let bg = async move {
-		let s = StatementDistribution::new(
+		let s = StatementDistributionSubsystem::new(
 			make_ferdie_keystore(),
 			statement_req_receiver,
 			Default::default(),
diff --git a/polkadot/node/service/src/overseer.rs b/polkadot/node/service/src/overseer.rs
index 08d94445df8..2441c688bab 100644
--- a/polkadot/node/service/src/overseer.rs
+++ b/polkadot/node/service/src/overseer.rs
@@ -59,9 +59,9 @@ pub use polkadot_node_core_candidate_validation::CandidateValidationSubsystem;
 pub use polkadot_node_core_chain_api::ChainApiSubsystem;
 pub use polkadot_node_core_chain_selection::ChainSelectionSubsystem;
 pub use polkadot_node_core_dispute_coordinator::DisputeCoordinatorSubsystem;
-pub use polkadot_node_core_provisioner::ProvisioningSubsystem as ProvisionerSubsystem;
+pub use polkadot_node_core_provisioner::ProvisionerSubsystem;
 pub use polkadot_node_core_runtime_api::RuntimeApiSubsystem;
-pub use polkadot_statement_distribution::StatementDistribution as StatementDistributionSubsystem;
+pub use polkadot_statement_distribution::StatementDistributionSubsystem;
 
 /// Arguments passed for overseer construction.
 pub struct OverseerGenArgs<'a, Spawner, RuntimeClient>
diff --git a/polkadot/node/core/provisioner/src/lib.rs b/polkadot/node/core/provisioner/src/lib.rs
index fc496800080..11c2f0aa9c1 100644
--- a/polkadot/node/core/provisioner/src/lib.rs
+++ b/polkadot/node/core/provisioner/src/lib.rs
@@ -91,7 +91,7 @@ impl InherentAfter {
 }
 
 /// A per-relay-parent job for the provisioning subsystem.
-pub struct ProvisioningJob {
+pub struct ProvisionerJob {
 	leaf: ActivatedLeaf,
 	receiver: mpsc::Receiver<ProvisionerMessage>,
 	backed_candidates: Vec<CandidateReceipt>,
@@ -144,7 +144,7 @@ pub enum Error {
 	BackedCandidateOrderingProblem,
 }
 
-impl JobTrait for ProvisioningJob {
+impl JobTrait for ProvisionerJob {
 	type ToJob = ProvisionerMessage;
 	type Error = Error;
 	type RunArgs = ();
@@ -164,7 +164,7 @@ impl JobTrait for ProvisioningJob {
 	) -> Pin<Box<dyn Future<Output = Result<(), Self::Error>> + Send>> {
 		async move {
 			let span = leaf.span.clone();
-			let job = ProvisioningJob::new(leaf, metrics, receiver);
+			let job = ProvisionerJob::new(leaf, metrics, receiver);
 
 			job.run_loop(sender.subsystem_sender(), PerLeafSpan::new(span, "provisioner"))
 				.await
@@ -173,7 +173,7 @@ impl JobTrait for ProvisioningJob {
 	}
 }
 
-impl ProvisioningJob {
+impl ProvisionerJob {
 	fn new(
 		leaf: ActivatedLeaf,
 		metrics: Metrics,
@@ -626,5 +626,5 @@ async fn select_disputes(
 		.collect())
 }
 
-/// The provisioning subsystem.
-pub type ProvisioningSubsystem<Spawner> = JobSubsystem<ProvisioningJob, Spawner>;
+/// The provisioner subsystem.
+pub type ProvisionerSubsystem<Spawner> = JobSubsystem<ProvisionerJob, Spawner>;
-- 
GitLab